@@ -56,6 +56,7 @@
 ( "c"                       , "file_type_c"                       ),
 ( "cake"                    , "file_type_cake"                    ),
 ( "cargo-lock"              , "file_type_rust"                    ),
+( "cc"                      , "file_type_cpp"                     ),
 ( "cer"                     , "file_type_cert"                    ),
 ( "cfignore"                , "file_type_cloudfoundry"            ),
 ( "cjm"                     , "file_type_clojure"                 ),
@@ -126,6 +127,7 @@
 ( "f4p"                     , "file_type_video"                   ),
 ( "f4v"                     , "file_type_video"                   ),
 ( "fbx"                     , "file_type_fbx"                     ),
+( "fnl"                     , "file_type_fennel"                  ),
 ( "fig"                     , "file_type_matlab"                  ),
 ( "firebaserc"              , "file_type_firebase"                ),
 ( "fish"                    , "file_type_shell"                   ),
@@ -196,6 +198,7 @@
 ( "jsonld"                  , "file_type_jsonld"                  ),
 ( "jsp"                     , "file_type_jsp"                     ),
 ( "jss"                     , "file_type_jss"                     ),
+( "jl"                      , "file_type_julia"                   ),
 ( "kdl"                     , "file_type_config"                  ),
 ( "key"                     , "file_type_key"                     ),
 ( "kit"                     , "file_type_codekit"                 ),
