@@ -1,13 +1,8 @@
-
-
 /// result of a full text search
 #[derive(Debug, Clone, Copy, PartialEq)]
 pub enum ContentSearchResult {
-
     /// the needle has been found at the given pos
-    Found {
-        pos: usize,
-    },
+    Found { pos: usize },
 
     /// the needle hasn't been found
     NotFound, // no match
@@ -18,6 +13,6 @@ pub enum ContentSearchResult {
 
 impl ContentSearchResult {
     pub fn is_found(self) -> bool {
-        matches!(self, Self::Found {..})
+        matches!(self, Self::Found { .. })
     }
 }
