@@ -1,21 +1,34 @@
 use {
     super::{
-        help_content,
         SearchModeHelp,
+        help_content,
     },
     crate::{
         app::*,
-        command::{Command, TriggerType},
+        command::{
+            Command,
+            TriggerType,
+        },
         conf::Conf,
-        display::{Screen, W},
+        display::{
+            Screen,
+            W,
+        },
         errors::ProgramError,
         launchable::Launchable,
         pattern::*,
         tree::TreeOptions,
         verb::*,
     },
-    std::path::{Path, PathBuf},
-    termimad::{Area, FmtText, TextView},
+    std::path::{
+        Path,
+        PathBuf,
+    },
+    termimad::{
+        Area,
+        FmtText,
+        TextView,
+    },
 };
 
 /// an application state dedicated to help
@@ -36,7 +49,8 @@ impl HelpState {
         con: &AppContext,
     ) -> HelpState {
         let text_area = Area::uninitialized(); // will be fixed at drawing time
-        let config_path = con.config_paths
+        let config_path = con
+            .config_paths
             .first()
             .cloned()
             .unwrap_or_else(Conf::default_location);
@@ -53,12 +67,14 @@ impl HelpState {
 }
 
 impl PanelState for HelpState {
-
     fn get_type(&self) -> PanelStateType {
         PanelStateType::Help
     }
 
-    fn set_mode(&mut self, mode: Mode) {
+    fn set_mode(
+        &mut self,
+        mode: Mode,
+    ) {
         self.mode = mode;
     }
 
@@ -94,7 +110,11 @@ impl PanelState for HelpState {
         })
     }
 
-    fn refresh(&mut self, _screen: Screen, _con: &AppContext) -> Command {
+    fn refresh(
+        &mut self,
+        _screen: Screen,
+        _con: &AppContext,
+    ) -> Command {
         self.dirty = true;
         Command::empty()
     }
@@ -128,12 +148,13 @@ impl PanelState for HelpState {
         }
         let mut expander = help_content::expander();
         expander.set("version", env!("CARGO_PKG_VERSION"));
-        let config_paths: Vec<String> = con.config_paths.iter()
+        let config_paths: Vec<String> = con
+            .config_paths
+            .iter()
             .map(|p| p.to_string_lossy().to_string())
             .collect();
         for path in &config_paths {
-            expander.sub("config-files")
-                .set("path", path);
+            expander.sub("config-files").set("path", path);
         }
         let verb_rows = super::help_verbs::matching_verb_rows(&self.pattern, con);
         for row in &verb_rows {
@@ -202,6 +223,7 @@ impl PanelState for HelpState {
     fn on_internal(
         &mut self,
         w: &mut W,
+        invocation_parser: Option<&InvocationParser>,
         internal_exec: &InternalExecution,
         input_invocation: Option<&VerbInvocation>,
         trigger_type: TriggerType,
@@ -225,11 +247,7 @@ impl PanelState for HelpState {
             }
             line_up | line_up_no_cycle => {
                 let dy = get_arg(input_invocation, internal_exec, 1);
-                self.scroll = if self.scroll > dy {
-                    self.scroll - dy
-                } else {
-                    0
-                };
+                self.scroll = self.scroll.saturating_sub(dy);
                 CmdResult::Keep
             }
             open_stay => match opener::open(Conf::default_location()) {
@@ -240,11 +258,7 @@ impl PanelState for HelpState {
                 Err(e) => CmdResult::DisplayError(format!("{e:?}")),
             },
             // FIXME check we can't use the generic one
-            open_leave => {
-                CmdResult::from(Launchable::opener(
-                    Conf::default_location()
-                ))
-            }
+            open_leave => CmdResult::from(Launchable::opener(Conf::default_location())),
             page_down => {
                 self.scroll += self.text_area.height as usize;
                 CmdResult::Keep
@@ -260,6 +274,7 @@ impl PanelState for HelpState {
             }
             _ => self.on_internal_generic(
                 w,
+                invocation_parser,
                 internal_exec,
                 input_invocation,
                 trigger_type,
@@ -269,4 +284,3 @@ impl PanelState for HelpState {
         })
     }
 }
-
